library(ggdendro)
library(dendextend)
library(dendextendRcpp)
library(plyr)
library(ggplot2)
library(corrplot)
library(FactoMineR)
library(factoextra)
library(car)
library(reshape2)
library(scales)
library(lme4)
library(stringr)
library(grid)
library(gridExtra)
library(data.table)


#*************************************************************************************************
# Getting Color Transform Data
#*************************************************************************************************
img_to_barcode <- read.csv("../data/temperature/SnapshotInfo.csv",header = T,stringsAsFactors = F)
img_to_barcode <- img_to_barcode[img_to_barcode$tiles != "",]
colnames(img_to_barcode)[3] <- "Barcodes"

ch <- read.table("../data/temperature/shapes.txt",header = F,stringsAsFactors = F,sep = " ")[,-22]
colnames(ch) <- c("meta","area","hull_area","solidity","perimeter","width","height","cmx","cmy","hull_verticies","ex","ey","emajor","eminor","angle","eccen","circ","round","ar","fd","det")
ch <- ch[,c("meta","det")]
ch$id <- substring(as.character(sapply(ch$meta,function(i) strsplit(i,"/")[[1]][2])),9)
ch$imgname <- as.character(sapply(ch$meta,function(i) strsplit(strsplit(i,"/")[[1]][3],"[.]")[[1]][1]))
ch <- join(ch,img_to_barcode[,c("id","Barcodes","timestamp")],by="id")
ch$timestamp <- strptime(ch$timestamp,format = "%Y-%m-%d %H:%M:%S")
ch$timestamp_min <- ch$timestamp-45
ch$timestamp_max <- ch$timestamp+45
temps <- read.csv("../data/temperature/all_hobos.csv",header=T,stringsAsFactors = F)
temps$Time <- strptime(temps$Time,format = "%m/%d/%y %I:%M:%S %p")
temps <- na.omit(temps)
ch$temp <- 0
for(i in 1:nrow(ch)){
  ch[i,"temp"] <- mean(temps[temps$Time %between% c(ch[i,"timestamp_min"],ch[i,"timestamp_max"]),"Temp_c"])
}
ch <- ch[order(ch$timestamp),]
ch$seq <- 1:nrow(ch)
ch$exp <- ordered(c(rep("Diurnal Temp",38),rep("Constant Temp",nrow(ch)-38)),levels=c("Diurnal Temp","Constant Temp"))
ch$hr <- as.POSIXlt(ch$timestamp)$hour
ch$status <- sapply(ch$hr,function(i) if(i %in% 7:21){"32°C Daytime"}else{"22°C Nighttime"})
ch$ZT <- sapply(as.numeric(ch$hr),function(i)if(i < 7){17+i}else{i-7})
table(ch$ZT)
ylab <- "Temperature (°C)"


#*************************************************************************************************
# Plotting
#*************************************************************************************************
ch_agg <- aggregate(data=ch,temp~exp+ZT+status,FUN = "mean")

p <- ggplot(ch_agg,aes(ZT,temp))+
  facet_grid(~exp)+
  geom_point(aes(color=status))+
  scale_x_continuous(limits=c(0,19),breaks = seq(from=0,to=23,by=2))+
  scale_color_manual(values=rev(c("darkorange","dodgerblue4")))+
  xlab("ZT")+
  labs(y=ylab)+
  theme_light()+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(axis.text = element_text(size = 14),
        axis.title= element_text(size = 18))+
  theme(strip.background=element_rect(fill="gray50"),
        strip.text.x=element_text(size=14,color="white"),
        strip.text.y=element_text(size=14,color="white"))
p
ggsave("cc_experiment_temperature.png",width=8.5,height=3.92,plot = p, dpi = 300)

ch_agg <- aggregate(data=ch,det~exp+ZT+status,FUN = "mean")

p <- ggplot(ch_agg,aes(ZT,det))+
  facet_grid(~exp)+
  geom_point(aes(color=status))+
  scale_color_manual(values=rev(c("darkorange","dodgerblue4")))+
  xlab("ZT")+
  ylab("Deviance (D)")+
  scale_x_continuous(limits=c(0,19),breaks = seq(from=0,to=23,by=2))+
  theme_light()+
  theme(plot.title = element_text(hjust = 0.5))+
  theme(axis.text = element_text(size = 14),
        axis.title= element_text(size = 18))+
  theme(strip.background=element_rect(fill="gray50"),
        strip.text.x=element_text(size=14,color="white"),
        strip.text.y=element_text(size=14,color="white"))
p
ggsave("cc_experiment_det.png",width=8.5,height=3.92,plot = p, dpi = 300)